==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/HighDensityScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescriptionMetadata } from "./ProgressiveLoadStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighDensityScatterSeriesDescription } from "./HighDensityScatterSeriesDescription";
/**
 * @hidden
 */
var HighDensityScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HighDensityScatterSeriesDescriptionMetadata, _super);
    function HighDensityScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HighDensityScatterSeriesDescriptionMetadata.b = function (a) {
        if (HighDensityScatterSeriesDescriptionMetadata.a == null) {
            HighDensityScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HighDensityScatterSeriesDescriptionMetadata.c(HighDensityScatterSeriesDescriptionMetadata.a);
        }
        if (a.j(HighDensityScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(HighDensityScatterSeriesDescriptionMetadata.a);
        ProgressiveLoadStatusEventArgsDescriptionMetadata.d(a);
    };
    HighDensityScatterSeriesDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("XMemberPath", "String");
        a.item("XMemberAsLegendLabel", "String");
        a.item("YMemberAsLegendLabel", "String");
        a.item("XMemberAsLegendUnit", "String");
        a.item("YMemberAsLegendUnit", "String");
        a.item("YMemberPath", "String");
        a.item("UseBruteForce", "Boolean");
        a.item("ProgressiveLoad", "Boolean");
        a.item("HeatMinimum", "Number:double");
        a.item("HeatMaximum", "Number:double");
        a.item("HeatMinimumColor", "Color");
        a.item("HeatMaximumColor", "Color");
        a.item("PointExtent", "Number:int");
        a.item("ProgressiveStatus", "Number:int");
        a.item("ProgressiveLoadStatusChangedRef", "EventRef::progressiveLoadStatusChanged");
    };
    HighDensityScatterSeriesDescriptionMetadata.d = function (a) {
        HighDensityScatterSeriesDescriptionMetadata.b(a);
        a.aa("HighDensityScatterSeries", function () { return new HighDensityScatterSeriesDescription(); });
        a.z("HighDensityScatterSeries", HighDensityScatterSeriesDescriptionMetadata.a);
    };
    HighDensityScatterSeriesDescriptionMetadata.$t = markType(HighDensityScatterSeriesDescriptionMetadata, 'HighDensityScatterSeriesDescriptionMetadata');
    HighDensityScatterSeriesDescriptionMetadata.a = null;
    return HighDensityScatterSeriesDescriptionMetadata;
}(Base));
export { HighDensityScatterSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/HighDensityScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescriptionMetadata } from "./ProgressiveLoadStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighDensityScatterSeriesDescription } from "./HighDensityScatterSeriesDescription";
/**
 * @hidden
 */
var HighDensityScatterSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(HighDensityScatterSeriesDescriptionMetadata, _super);
    function HighDensityScatterSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HighDensityScatterSeriesDescriptionMetadata.b = function (a) {
        if (HighDensityScatterSeriesDescriptionMetadata.a == null) {
            HighDensityScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HighDensityScatterSeriesDescriptionMetadata.c(HighDensityScatterSeriesDescriptionMetadata.a);
        }
        if (a.k(HighDensityScatterSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(HighDensityScatterSeriesDescriptionMetadata.a);
        ProgressiveLoadStatusEventArgsDescriptionMetadata.d(a);
    };
    HighDensityScatterSeriesDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("XMemberPath", "String");
        a.item("XMemberAsLegendLabel", "String");
        a.item("YMemberAsLegendLabel", "String");
        a.item("XMemberAsLegendUnit", "String");
        a.item("YMemberAsLegendUnit", "String");
        a.item("YMemberPath", "String");
        a.item("UseBruteForce", "Boolean");
        a.item("ProgressiveLoad", "Boolean");
        a.item("HeatMinimum", "Number:double");
        a.item("HeatMaximum", "Number:double");
        a.item("HeatMinimumColor", "Color");
        a.item("HeatMaximumColor", "Color");
        a.item("PointExtent", "Number:int");
        a.item("ProgressiveStatus", "Number:int");
        a.item("ProgressiveLoadStatusChangedRef", "EventRef::progressiveLoadStatusChanged");
    };
    HighDensityScatterSeriesDescriptionMetadata.d = function (a) {
        HighDensityScatterSeriesDescriptionMetadata.b(a);
        a.ac("HighDensityScatterSeries", function () { return new HighDensityScatterSeriesDescription(); });
        a.ab("HighDensityScatterSeries", HighDensityScatterSeriesDescriptionMetadata.a);
    };
    HighDensityScatterSeriesDescriptionMetadata.$t = markType(HighDensityScatterSeriesDescriptionMetadata, 'HighDensityScatterSeriesDescriptionMetadata');
    HighDensityScatterSeriesDescriptionMetadata.a = null;
    return HighDensityScatterSeriesDescriptionMetadata;
}(Base));
export { HighDensityScatterSeriesDescriptionMetadata };
